.. _doc-index:

########################
  Camelot Documentation
########################

This is the reference documentation for developing projects using the Camelot
library.  The first time Camelot developer is encouraged to read
:ref:`doc-models` and :ref:`doc-admin`.

The section :ref:`doc-threads` is for developers whishing to maintain a
responsive UI when faced with significant delays in their application code.

All other sections can be read on an as needed base.

.. toctree::

   install.rst
   models.rst
   admin.rst
   application_admin.rst
   forms.rst
   actions.rst
   delegates.rst
   charts.rst
   documents.rst
   data_model.rst
   fixtures.rst
   manage.rst
   schemas.rst
   shortcuts.rst
   threads.rst
   faq.rst
